@@ -3,7 +3,7 @@
 # This script updates Double Commander Open Build Service (OBS) repository
 
 # Set Double Commander version
-DC_VER=0.6.6
+DC_VER=0.7.1
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
@@ -30,11 +30,6 @@ update_doublecmd()
   # Save revision number
   DC_REVISION=`$(pwd)/update-revision.sh ../../ $DC_SOURCE_DIR`
 
-  # Remove help files
-  rm -rf $DC_SOURCE_DIR/doc/en
-  rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk
-
   # Prepare doublecmd-*.spec file
   cp -a rpm/doublecmd-*.spec $DC_TEMP_DIR
 
